@@ -1,3 +1,4 @@
+from django.utils import six
 from rq.decorators import job as _rq_job
 
 from .queues import get_queue
@@ -18,14 +19,7 @@ def job(func_or_queue, connection=None, *args, **kwargs):
         func = None
         queue = func_or_queue
 
-    try:
-        from django.utils import six
-        string_type = six.string_types
-    except ImportError:
-        # for django lt v1.5 and python 2
-        string_type = basestring
-
-    if isinstance(queue, string_type):
+    if isinstance(queue, six.string_types):
         try:
             queue = get_queue(queue)
             if connection is None:
