@@ -1,3 +1,5 @@
+from operator import itemgetter
+
 from django.conf import settings
 from django.core.exceptions import ImproperlyConfigured
 
@@ -13,7 +15,10 @@ BURST = getattr(settings, 'RQ_BURST', False)
 
 # All queues in list format so we can get them by index, includes failed queues
 QUEUES_LIST = []
-for key, value in QUEUES.items():
+for key, value in sorted(QUEUES.items(), key=itemgetter(0)):
     QUEUES_LIST.append({'name': key, 'connection_config': value})
 for config in get_unique_connection_configs():
     QUEUES_LIST.append({'name': 'failed', 'connection_config': config})
+
+# Get exception handlers
+EXCEPTION_HANDLERS = getattr(settings, 'RQ_EXCEPTION_HANDLERS', [])
