@@ -1,22 +1,30 @@
 from django.contrib.auth.models import User
-from django.core.exceptions import ImproperlyConfigured
 from django.core.management import call_command
 from django.core.urlresolvers import reverse
 from django.test import TestCase
-from django.utils.unittest import skipIf
+try:
+    from unittest import skipIf
+except ImportError:
+    from django.utils.unittest import skipIf
 from django.test.client import Client
-from django.test.utils import override_settings
+try:
+    from django.test import override_settings
+except ImportError:
+    from django.test.utils import override_settings
 from django.conf import settings
 
 from rq import get_current_job, Queue
 from rq.job import Job
+from rq.registry import (DeferredJobRegistry, FinishedJobRegistry,
+                         StartedJobRegistry)
 
 from django_rq.decorators import job
 from django_rq.queues import (
     get_connection, get_queue, get_queue_by_index, get_queues,
-    get_unique_connection_configs
+    get_unique_connection_configs, DjangoRQ
 )
 from django_rq import thread_queue
+from django_rq.templatetags.django_rq import to_localtime
 from django_rq.workers import get_worker
 
 
@@ -124,6 +132,36 @@ class QueuesTest(TestCase):
         self.assertEqual(connection_kwargs['db'], 4)
         self.assertEqual(connection_kwargs['password'], 'password')
 
+    def test_get_queue_url_with_db(self):
+        """
+        Test that get_queue use the right parameters for queues using URL for
+        connection, where URL contains the db number (either as querystring
+        or path segment).
+        """
+        config = QUEUES['url_with_db']
+        queue = get_queue('url_with_db')
+        connection_kwargs = queue.connection.connection_pool.connection_kwargs
+        self.assertEqual(queue.name, 'url_with_db')
+        self.assertEqual(connection_kwargs['host'], 'host')
+        self.assertEqual(connection_kwargs['port'], 1234)
+        self.assertEqual(connection_kwargs['db'], 5)
+        self.assertEqual(connection_kwargs['password'], 'password')
+
+    def test_get_queue_url_with_db_default(self):
+        """
+        Test that get_queue use the right parameters for queues using URL for
+        connection, where no DB given and URL does not contain the db number
+        (redis-py defaults to 0, should not break).
+        """
+        config = QUEUES['url_default_db']
+        queue = get_queue('url_default_db')
+        connection_kwargs = queue.connection.connection_pool.connection_kwargs
+        self.assertEqual(queue.name, 'url_default_db')
+        self.assertEqual(connection_kwargs['host'], 'host')
+        self.assertEqual(connection_kwargs['port'], 1234)
+        self.assertEqual(connection_kwargs['db'], 0)
+        self.assertEqual(connection_kwargs['password'], 'password')
+
     def test_get_queue_test(self):
         """
         Test that get_queue use the right parameters for `test`
@@ -150,6 +188,25 @@ class QueuesTest(TestCase):
         """
         self.assertRaises(ValueError, get_queues, 'default', 'test')
 
+    def test_pass_queue_via_commandline_args(self):
+        """
+        Checks that passing queues via commandline arguments works
+        """
+        queue_names = ['django_rq_test', 'django_rq_test2']
+        jobs = []
+        for queue_name in queue_names:
+            queue = get_queue(queue_name)
+            jobs.append({
+                'job': queue.enqueue(divide, 42, 1),
+                'finished_job_registry': FinishedJobRegistry(queue.name, queue.connection),
+            })
+
+        call_command('rqworker', *queue_names, burst=True)
+
+        for job in jobs:
+            self.assertTrue(job['job'].is_finished)
+            self.assertIn(job['job'].id, job['finished_job_registry'].get_job_ids())
+
     def test_get_unique_connection_configs(self):
         connection_params_1 = {
             'HOST': 'localhost',
@@ -180,6 +237,31 @@ class QueuesTest(TestCase):
         self.assertEqual(get_unique_connection_configs(config),
                          [connection_params_1])
 
+    def test_get_unique_connection_configs_with_different_timeout(self):
+        connection_params_1 = {
+            'HOST': 'localhost',
+            'PORT': 6379,
+            'DB': 0,
+        }
+        connection_params_2 = {
+            'HOST': 'localhost',
+            'PORT': 6379,
+            'DB': 1,
+        }
+        queue_params_a = dict(connection_params_1)
+        queue_params_b = dict(connection_params_2)
+        queue_params_c = dict(connection_params_2)
+        queue_params_c["DEFAULT_TIMEOUT"] = 1
+        config = {
+            'default': queue_params_a,
+            'test_b': queue_params_b,
+            'test_c': queue_params_c,
+        }
+        unique_configs = get_unique_connection_configs(config)
+        self.assertEqual(len(unique_configs), 2)
+        self.assertIn(connection_params_1, unique_configs)
+        self.assertIn(connection_params_2, unique_configs)
+
     def test_async(self):
         """
         Checks whether asynchronous settings work
@@ -248,13 +330,6 @@ class DecoratorTest(TestCase):
         result.delete()
 
 
-class ConfigTest(TestCase):
-    @override_settings(RQ_QUEUES=None)
-    def test_empty_queue_setting_raises_exception(self):
-        # Raise an exception if RQ_QUEUES is not defined
-        self.assertRaises(ImproperlyConfigured, get_connection)
-
-
 @override_settings(RQ={'AUTOCOMMIT': True})
 class WorkersTest(TestCase):
     def test_get_worker_default(self):
@@ -282,7 +357,7 @@ class WorkersTest(TestCase):
         """
         queue = get_queue()
         job = queue.enqueue(access_self)
-        call_command('rqworker', burst=True)
+        call_command('rqworker', '--burst')
         failed_queue = Queue(name='failed', connection=queue.connection)
         self.assertFalse(job.id in failed_queue.job_ids)
         job.delete()
@@ -298,6 +373,7 @@ class ViewTest(TestCase):
         user.save()
         self.client = Client()
         self.client.login(username=user.username, password='pass')
+        get_queue('django_rq_test').connection.flushall()
 
     def test_requeue_job(self):
         """
@@ -391,6 +467,45 @@ class ViewTest(TestCase):
         self.assertFalse(Job.exists(job.id, connection=queue.connection))
         self.assertNotIn(job.id, queue.job_ids)
 
+    def test_finished_jobs(self):
+        """Ensure that finished jobs page works properly."""
+        queue = get_queue('django_rq_test')
+        queue_index = get_queue_index('django_rq_test')
+
+        job = queue.enqueue(access_self)
+        registry = FinishedJobRegistry(queue.name, queue.connection)
+        registry.add(job, 2)
+        response = self.client.get(
+            reverse('rq_finished_jobs', args=[queue_index])
+        )
+        self.assertEqual(response.context['jobs'], [job])
+
+    def test_started_jobs(self):
+        """Ensure that active jobs page works properly."""
+        queue = get_queue('django_rq_test')
+        queue_index = get_queue_index('django_rq_test')
+
+        job = queue.enqueue(access_self)
+        registry = StartedJobRegistry(queue.name, queue.connection)
+        registry.add(job, 2)
+        response = self.client.get(
+            reverse('rq_started_jobs', args=[queue_index])
+        )
+        self.assertEqual(response.context['jobs'], [job])
+
+    def test_deferred_jobs(self):
+        """Ensure that active jobs page works properly."""
+        queue = get_queue('django_rq_test')
+        queue_index = get_queue_index('django_rq_test')
+
+        job = queue.enqueue(access_self)
+        registry = DeferredJobRegistry(queue.name, queue.connection)
+        registry.add(job, 2)
+        response = self.client.get(
+            reverse('rq_deferred_jobs', args=[queue_index])
+        )
+        self.assertEqual(response.context['jobs'], [job])
+
 
 class ThreadQueueTest(TestCase):
 
@@ -523,3 +638,35 @@ class RedisCacheTest(TestCase):
         self.assertEqual(connection_kwargs['port'], int(cachePort))
         self.assertEqual(connection_kwargs['db'], int(cacheDBNum))
         self.assertEqual(connection_kwargs['password'], None)
+
+
+class DummyQueue(DjangoRQ):
+    """Just Fake class for the following test"""
+
+
+class QueueClassTest(TestCase):
+
+    def test_default_queue_class(self):
+        queue = get_queue('test')
+        self.assertIsInstance(queue, DjangoRQ)
+
+    def test_for_queue(self):
+        queue = get_queue('test1')
+        self.assertIsInstance(queue, DummyQueue)
+
+    def test_in_kwargs(self):
+        queue = get_queue('test', queue_class=DummyQueue)
+        self.assertIsInstance(queue, DummyQueue)
+
+
+@override_settings(RQ={'AUTOCOMMIT': True})
+class TemplateTagTest(TestCase):
+
+    def test_to_localtime(self):
+        with self.settings(TIME_ZONE='Asia/Jakarta'):
+            queue = get_queue()
+            job = queue.enqueue(access_self)
+            time = to_localtime(job.created_at)
+
+            self.assertIsNotNone(time.tzinfo)
+            self.assertEqual(time.strftime("%z"), '+0700')
